sysuse nlsw88.dta, clear
sysdescribe nlsw88.dta


sum 
* generating the dummy vars for diff races
gen white=1 if race==1 
replace white=0 if race==2 | race==3

gen black=1 if race==2
replace black=0 if race==1 | race==3

* generating dummies for occupation types

gen prof_tech=1 if occupation==1
replace prof_tech=0 if prof_tech==.
label var prof_tech "Professional/technical"

gen managers=1 if occupation==2
replace managers=0 if managers==.
label var managers "Managers/admin" 

gen sales=1 if occupation==3
replace sales=0 if sales==.
label var sales "Sales" 

gen operatives=1 if occupation==6
replace operatives=0 if operatives==.
label var operatives "Operatives" 

* generating dummy vars for industry types

gen manufacturing=1 if industry==4
replace manufacturing=0 if manufacturing==.
label var manufacturing "Manufacturing" 

gen wholesale=1 if industry==6
replace wholesale=0 if wholesale==.
label var wholesale "Wholesale/Retail Trade" 

gen prof_serv=1 if industry==11
replace prof_serv=0 if prof_serv==.
label var prof_serv "Professional Services" 

* Describing the data

sum wage, detail
sum wage  age race married never_married grade ///
	collgrad south smsa c_city industry occupation union ///
	hours ttl_exp tenure, detail
	
*graph matrix wage grade ttl_exp age 	
twoway scatter wage grade || lfit wage grade 
twoway scatter wage ttl_exp || lfit wage ttl_exp



*** Running our regression ***
gen age2=age^2
gen lnwage=ln(wage)
gen ttl_exp2 = ttl_exp^2

*standard Mincer earnings function

reg lnwage ttl_exp ttl_exp2 grade

/*First, we look to the p-value of the F-test to see if the overall model is significant. 
With a pvalue of zero to four decimal places, the model is statistically significant.
The R-squared is 0.26, meaning that approximately 26% of the variability of hourly wage is accounted for by
the variables in the model. In this case, the adjusted R-squared indicates that about 26% of
the variability of wage is accounted for by the model, even after taking into account the
number of predictor variables in the model. The coefficients for each of the variables indicates
the amount of change one could expect in logwage given a one-unit change in the value of
that variable, given that all other variables in the model are held constant.*/

estat vif // for some vars the multicollinearity exist (>10)

*Modifying by adding other vars
reg lnwage age age2 white black married never_married grade ///
	collgrad south smsa c_city union hours ttl_exp tenure 

estat hettest
estat imtest, white

**** adding controls
by race, sort : summarize wage // checking whether the wage is different for racial groups

ttest wage, by(black)
ttest wage, by(white) //The corresponding two-tailed p-value is 0.0000, which is less than 0.05.  We conclude that the difference of means in wage between white and non-white is different from 0.

reg lnwage ttl_exp ttl_exp2 grade i.race
reg lnwage ttl_exp ttl_exp2 grade i.race collgrad
reg lnwage ttl_exp ttl_exp2 grade i.race collgrad i.occupation
reg lnwage ttl_exp ttl_exp2 grade i.race collgrad i.occupation i.industry
reg lnwage ttl_exp ttl_exp2 grade i.race collgrad i.occupation i.industry 

